@@ -189,8 +189,8 @@ static void store_table_in_file(char *filename, struct ebt_replace *repl)
 	int size;
 	int fd;
 
-	/* Start from an empty file with right priviliges */
-	if (!(fd = creat(filename, 0600))) {
+	/* Start from an empty file with the correct priviliges */
+	if ((fd = creat(filename, 0600)) == -1) {
 		ebt_print_error("Couldn't create file %s", filename);
 		return;
 	}
@@ -303,8 +303,9 @@ void ebt_deliver_counters(struct ebt_u_replace *u_repl)
 	new = newcounters;
 	while (cc != u_repl->cc) {
 		if (!next || next == entries->entries) {
-			while (chainnr < u_repl->num_chains && (!(entries = u_repl->chains[chainnr++]) ||
-			       (next = entries->entries->next) == entries->entries));
+			while (chainnr < u_repl->num_chains && (!(entries = u_repl->chains[chainnr]) ||
+			       (next = entries->entries->next) == entries->entries))
+				chainnr++;
 			if (chainnr == u_repl->num_chains)
 				break;
 		}
